=== modified file 'NEWS'
--- NEWS	2008-07-18 08:40:57 +0000
+++ NEWS	2008-07-21 14:46:05 +0000
@@ -152,6 +152,9 @@
     * Set locale from environment for third party libs.
       (Martin von Gagern, #128496)
 
+    * Handle a file turning in to a directory in TreeTransform.
+      (James Westby, #248448)
+
   DOCUMENTATION:
 
     * Added *Using stacked branches* to the User Guide.

=== modified file 'bzrlib/tests/test_transform.py'
--- bzrlib/tests/test_transform.py	2008-07-02 19:18:03 +0000
+++ bzrlib/tests/test_transform.py	2008-07-21 14:46:41 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006, 2007, 2008 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1215,6 +1215,21 @@
         self.assertContainsRe(str(err),
             "^File exists: .+/foo")
 
+    def test_file_to_directory(self):
+        wt = self.make_branch_and_tree('.')
+        self.build_tree(['foo'])
+        wt.add(['foo'])
+        tt = TreeTransform(wt)
+        self.addCleanup(tt.finalize)
+        foo_trans_id = tt.trans_id_tree_path("foo")
+        tt.delete_contents(foo_trans_id)
+        tt.create_directory(foo_trans_id)
+        bar_trans_id = tt.trans_id_tree_path("foo/bar")
+        tt.create_file(["aa\n"], bar_trans_id)
+        tt.version_file("bar-1", bar_trans_id)
+        tt.apply()
+        self.failUnlessExists("foo/bar")
+
 
 class TransformGroup(object):
 

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2008-07-02 19:18:03 +0000
+++ bzrlib/transform.py	2008-07-17 15:56:09 +0000
@@ -354,7 +354,11 @@
         try:
             mode = os.stat(self._tree.abspath(old_path)).st_mode
         except OSError, e:
-            if e.errno == errno.ENOENT:
+            if e.errno in (errno.ENOENT, errno.ENOTDIR):
+                # Either old_path doesn't exist, or the parent of the
+                # target is not a directory (but will be one eventually)
+                # Either way, we know it doesn't exist *right now*
+                # See also bug #248448
                 return
             else:
                 raise

